==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicDesktopIconUI__24DesktopIconBorder.h <==
// class javax.swing.plaf.basic.BasicDesktopIconUI$DesktopIconBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d976ecabff96ca8e javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$_init$908b6c65f42513bc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$_init$50afb7ea6b023e0e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__241$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$paintBorder$4a79b2eae89db578;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods	javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs	javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs {
	jint	left;
	jint	top;
	jint	right;
	jint	bottom;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object {
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicDesktopIconUI__24DesktopIconBorder.h <==
// class javax.swing.plaf.basic.BasicDesktopIconUI$DesktopIconBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d976ecabff96ca8e javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$_init$908b6c65f42513bc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$_init$50afb7ea6b023e0e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$paintBorder$4a79b2eae89db578;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vmethods	javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_refs	javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs {
	jint	left;
	jint	top;
	jint	right;
	jint	bottom;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$object {
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$vtype _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24DesktopIconBorder_H_ */
